@@ -1,5 +1,5 @@
 package DateTime::Format::DBI;
-# $Id: DBI.pm,v 1.3 2003/11/02 23:17:38 cfaerber Exp $
+# $Id: DBI.pm 4060 2008-09-12 18:59:06Z cfaerber $
 
 use strict;
 use vars qw ($VERSION);
@@ -7,13 +7,15 @@ use vars qw ($VERSION);
 use Carp;
 use DBI 1.21;
 
-$VERSION = '0.031';
+$VERSION = '0.032';
 $VERSION = $VERSION + 0.0;
 
 our %db_to_parser = (
   # lowercase for case-insensitivity!
   'mysql'	=> 'DateTime::Format::MySQL',
   'pg'		=> 'DateTime::Format::Pg',
+  'db2'		=> 'DateTime::Format::DB2',
+# 'oracle'	=> 'DateTime::Format::Oracle', # not tested
 );
 
 sub new {
@@ -38,6 +40,7 @@ sub new {
 
 DateTime::Format::DBI - Find a parser class for a database connection.
 
+
 =head1 SYNOPSIS
 
   use DBI;
@@ -56,10 +59,20 @@ DateTime::Format::DBI - Find a parser class for a database connection.
 This module finds a C<DateTime::Format::*> class that is suitable for the use with
 a given DBI connection (and C<DBD::*> driver).
 
+
 It currently supports the following drivers: 
+L<IBM DB2 (DB2)|DateTime::Format::DB2>,
 L<MySQL|DateTime::Format::MySQL>, 
+# L<Oracle|DateTime::Format::Oracle>,
 L<PostgreSQL (Pg)|DateTime::Format::Pg>.
 
+B<WARNING:> This module provides a quick method to find the
+correct parser/formatter class. However, this is usually not
+enough for full database abstraction. You will usually have to
+care for differences not only in datetime syntax but also in the
+syntax and semantics of SQL datetime functions (and other SQL
+commands).
+
 =head1 CLASS METHODS
 
 =over 4
@@ -135,11 +148,11 @@ list.  See http://lists.perl.org/ for more details.
 
 =head1 AUTHOR
 
-Claus A. Frber <perl@faerber.muc.de>
+Claus A. Färber <perl@cfaerber.name>
 
 =head1 COPYRIGHT
 
-Copyright  2003 Claus A. Frber.  All rights reserved.  
+Copyright © 2003-2008 Claus A. Färber.  All rights reserved.  
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
